==> vue-action-sheet-2.8.0.tgz: package/lib/mobile.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/action-sheet/vue";
import { defineComponent, $prefix, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import "@dftvue2-opentiny/vue-theme-mobile/action-sheet/index.css";
import BScroll from "@better-scroll/core";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "ActionSheet",
  props: [].concat(props, ["menus", "modelValue", "visible", "ellipsis", "height", "contentPosition", "contentStyle"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api,
      extendOptions: {
        BScroll
      }
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    staticClass: "tiny-mobile-action-sheet",
    on: {
      "click": _vm.visibleHandle
    }
  }, [!_vm.contentPosition ? _c("div", {
    staticClass: "tiny-mobile-action-sheet__mask",
    style: _vm.state.sheetMaskStyle
  }) : _vm._e(), _c("div", {
    ref: "scrollMenu",
    class: ["tiny-mobile-action-sheet__content", _vm.state.toggle ? "is-toggle" : "", _vm.contentPosition ? "" : "is-not-content"],
    style: [_vm.state.sheetContentStyle]
  }, [_c("div", {
    class: ["tiny-mobile-action-sheet__menu", _vm.ellipsis ? "is-ellipsis" : ""]
  }, _vm._l(_vm.menus, function(item, index) {
    return _c("div", {
      key: index,
      class: ["tiny-mobile-action-sheet__item", item.warn ? "is-warn" : "", item.id === _vm.modelValue || item.id === _vm.state.active ? "is-active" : ""],
      style: _vm.state.contentStyle,
      on: {
        "click": function click($event) {
          return _vm.menuHandle(item, index);
        }
      }
    }, [_vm._t("item", function() {
      return [_vm._v(" " + _vm._s(item.label) + " ")];
    }, {
      "item": item
    })], 2);
  }), 0)]), _vm.contentPosition ? _c("div", {
    staticClass: "tiny-mobile-action-sheet__action"
  }, [_vm._t("action", function() {
    return [_c("div", {
      staticClass: "tiny-mobile-action-sheet__cancel",
      on: {
        "click": _vm.visibleHandle
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.actionSheet.cancel")) + " ")])];
  })], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-action-sheet-2.21.0.tgz: package/lib/mobile.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/action-sheet/vue';
import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import '@opentinyvue/vue-theme-mobile/action-sheet/index.css';
import BScroll from '@better-scroll/core';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "ActionSheet",
  props: [].concat(props, ["menus", "modelValue", "visible", "ellipsis", "contentPosition", "contentStyle", "height", "valueField", "textField", "contentClass"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      extendOptions: {
        BScroll
      }
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible,
      expression: "visible"
    }],
    staticClass: "tiny-mobile-action-sheet",
    on: {
      "click": _vm.hide
    }
  }, [!_vm.contentPosition ? _c("div", {
    staticClass: "tiny-mobile-action-sheet__mask",
    style: _vm.state.sheetMaskStyle
  }) : _vm._e(), _c("div", {
    ref: "scrollMenu",
    class: ["tiny-mobile-action-sheet__content", _vm.state.toggle ? "is-toggle" : "", _vm.contentPosition ? "" : "is-not-content"],
    style: [_vm.state.sheetContentStyle]
  }, [_c("div", {
    class: ["tiny-mobile-action-sheet__menu", _vm.ellipsis ? "is-ellipsis" : ""]
  }, _vm._l(_vm.menus, function(item, index) {
    return _c("div", {
      key: index,
      class: ["tiny-mobile-action-sheet__item", item.warn ? "is-warn" : "", item[_vm.valueField] === _vm.modelValue ? "is-active" : ""],
      style: _vm.state.contentStyle,
      on: {
        "click": function click($event) {
          return _vm.selectOption(item, index);
        }
      }
    }, [_vm._t("item", function() {
      return [_vm._v(" " + _vm._s(item[_vm.textField]) + " ")];
    }, {
      "item": item
    })], 2);
  }), 0)]), _vm.contentPosition ? _c("div", {
    staticClass: "tiny-mobile-action-sheet__action"
  }, [_vm._t("action", function() {
    return [_c("div", {
      staticClass: "tiny-mobile-action-sheet__cancel",
      on: {
        "click": _vm.hide
      }
    }, [_vm._v(" " + _vm._s(_vm.t("ui.actionSheet.cancel")) + " ")])];
  })], 2) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
